﻿using Eco.Gameplay.Skills;
using Eco.Gameplay.Systems.TextLinks;

namespace Eco.Mods.TechTree
{
    using System;
    using System.Collections.Generic;
    using Eco.Core.Items;
    using Eco.Gameplay.Components;
    using Eco.Gameplay.Components.Auth;
    using Eco.Gameplay.Items;
    using Eco.Gameplay.Objects;
    using Eco.Shared.Math;
    using Eco.Shared.Localization;
    using Eco.Shared.Serialization;
    
    [Serialized]
    [LocDisplayName("Steam Truck Purple")]
    [Weight(25000)]  
    [AirPollution(0.2f)] 
    [Ecopedia("CavRnMods", "Colored Vehicles", createAsSubPage: true, display: InPageTooltip.DynamicTooltip)]     
    [Tag("ColoredSteamTruck", 1)]
    public partial class SteamTruckPurpleItem : WorldObjectItem<SteamTruckPurpleObject>
    {
        public override LocString DisplayDescription { get { return Localizer.DoStr("A purple truck that runs on steam."); } }
    }
    
      
    public class PaintSteamTruckPurpleRecipe : RecipeFamily
    {
        public PaintSteamTruckPurpleRecipe()
        {
            this.Initialize(Localizer.DoStr("Paint Steam Truck Purple"), typeof(PaintSteamTruckPurpleRecipe));
            this.Recipes = new List<Recipe>
            {
                new Recipe(
                    "Paint Steam Truck Purple",
                    Localizer.DoStr("Paint Steam Truck Purple"),
                    new IngredientElement[]
                    {
                        new IngredientElement(typeof(SteamTruckItem), 1, true), 
                        new IngredientElement(typeof(BeetItem), 40, typeof(MechanicsSkill), typeof(MechanicsLavishResourcesTalent)),  
                    },
                    new CraftingElement<SteamTruckPurpleItem>()
                )
            };
            this.ExperienceOnCraft = 0.1f;  
            this.LaborInCalories = CreateLaborInCaloriesValue(500, typeof(MechanicsSkill), typeof(PaintSteamTruckPurpleRecipe), this.UILink()); 
            this.CraftMinutes = CreateCraftTimeValue(typeof(PaintSteamTruckPurpleRecipe), this.UILink(), 10, typeof(MechanicsSkill));    

            this.Initialize(Localizer.DoStr("Paint Steam Truck Purple"), typeof(PaintSteamTruckPurpleRecipe));
            CraftingComponent.AddRecipe(typeof(AdvancedPaintingTableObject), this);
        }
    }

    [Serialized]
    [RequireComponent(typeof(StandaloneAuthComponent))]
    [RequireComponent(typeof(FuelSupplyComponent))]              
    [RequireComponent(typeof(FuelConsumptionComponent))]         
    [RequireComponent(typeof(PublicStorageComponent))]      
    [RequireComponent(typeof(MovableLinkComponent))]        
    [RequireComponent(typeof(AirPollutionComponent))]       
    [RequireComponent(typeof(VehicleComponent))]
    [RequireComponent(typeof(ModularStockpileComponent))]   
    [RequireComponent(typeof(TailingsReportComponent))]     
    public partial class SteamTruckPurpleObject : PhysicsWorldObject, IRepresentsItem
    {
        static SteamTruckPurpleObject()
        {
            WorldObject.AddOccupancy<SteamTruckPurpleObject>(new List<BlockOccupancy>(0));
        }

        public override LocString DisplayName { get { return Localizer.DoStr("Steam Truck Purple"); } }
        public Type RepresentedItemType { get { return typeof(SteamTruckPurpleItem); } }

        private static string[] fuelTagList = new string[]
        {
            "Burnable Fuel"
        };

        private SteamTruckPurpleObject() { }

        protected override void Initialize()
        {
            base.Initialize();
            
            this.GetComponent<PublicStorageComponent>().Initialize(24, 5000000);           
            this.GetComponent<FuelSupplyComponent>().Initialize(2, fuelTagList);           
            this.GetComponent<FuelConsumptionComponent>().Initialize(25);    
            this.GetComponent<AirPollutionComponent>().Initialize(0.2f);            
            this.GetComponent<VehicleComponent>().Initialize(18, 2, 2);
            this.GetComponent<StockpileComponent>().Initialize(new Vector3i(2,2,3));  
        }
    }
}
