using Eco.Gameplay.Skills;
using Eco.Gameplay.Systems.TextLinks;

namespace Eco.Mods.TechTree
{
    using System;
    using System.Collections.Generic;
    using Eco.Core.Items;
    using Eco.Gameplay.Components;
    using Eco.Gameplay.Components.Auth;
    using Eco.Gameplay.Items;
    using Eco.Gameplay.Objects;
    using Eco.Shared.Math;
    using Eco.Shared.Localization;
    using Eco.Shared.Serialization;
    
    [Serialized]
    [LocDisplayName("Truck Purple")]
    [Weight(25000)]  
    [AirPollution(0.5f)] 
    [Ecopedia("CavRnMods", "Colored Vehicles", createAsSubPage: true, display: InPageTooltip.DynamicTooltip)]               
    [Tag("ColoredTruck", 1)]
    public partial class TruckPurpleItem : WorldObjectItem<TruckPurpleObject>
    {
        public override LocString DisplayDescription { get { return Localizer.DoStr("Modern purple truck for hauling sizable loads."); } }
    }
    
      
    public class PaintTruckPurpleRecipe : RecipeFamily
    {
        public PaintTruckPurpleRecipe()
        {
            this.Initialize(Localizer.DoStr("Paint Truck Purple"), typeof(PaintTruckPurpleRecipe));
            this.Recipes = new List<Recipe>
            {
                new Recipe(
                    "Paint Truck Purple",
                    Localizer.DoStr("Paint Truck Purple"),
                    new IngredientElement[]
                    {
                        new IngredientElement(typeof(TruckItem), 1, true), 
                        new IngredientElement(typeof(BeetItem), 60, typeof(IndustrySkill), typeof(IndustryLavishResourcesTalent)),  
                    },
                    new CraftingElement<TruckPurpleItem>()
                )
            };
            this.ExperienceOnCraft = 0.1f;  
            this.LaborInCalories = CreateLaborInCaloriesValue(750, typeof(IndustrySkill), typeof(PaintTruckPurpleRecipe), this.UILink()); 
            this.CraftMinutes = CreateCraftTimeValue(typeof(PaintTruckPurpleRecipe), this.UILink(), 15, typeof(IndustrySkill));    

            this.Initialize(Localizer.DoStr("Paint Truck Purple"), typeof(PaintTruckPurpleRecipe));
            CraftingComponent.AddRecipe(typeof(AdvancedPaintingTableObject), this);
        }
    }

    [Serialized]
    [RequireComponent(typeof(StandaloneAuthComponent))]
    [RequireComponent(typeof(FuelSupplyComponent))]              
    [RequireComponent(typeof(FuelConsumptionComponent))]         
    [RequireComponent(typeof(PublicStorageComponent))]      
    [RequireComponent(typeof(MovableLinkComponent))]        
    [RequireComponent(typeof(AirPollutionComponent))]       
    [RequireComponent(typeof(VehicleComponent))]
    [RequireComponent(typeof(ModularStockpileComponent))]   
    [RequireComponent(typeof(TailingsReportComponent))]     
    public partial class TruckPurpleObject : PhysicsWorldObject, IRepresentsItem
    {
        static TruckPurpleObject()
        {
            WorldObject.AddOccupancy<TruckPurpleObject>(new List<BlockOccupancy>(0));
        }

        public override LocString DisplayName { get { return Localizer.DoStr("Truck Purple"); } }
        public Type RepresentedItemType { get { return typeof(TruckPurpleItem); } }

        private static string[] fuelTagList = new string[]
        {
            "Liquid Fuel"
        };

        private TruckPurpleObject() { }

        protected override void Initialize()
        {
            base.Initialize();
            
            this.GetComponent<PublicStorageComponent>().Initialize(36, 8000000);           
            this.GetComponent<FuelSupplyComponent>().Initialize(2, fuelTagList);           
            this.GetComponent<FuelConsumptionComponent>().Initialize(25);    
            this.GetComponent<AirPollutionComponent>().Initialize(0.5f);            
            this.GetComponent<VehicleComponent>().Initialize(20, 2, 2);
            this.GetComponent<StockpileComponent>().Initialize(new Vector3i(2,2,3));  
        }
    }
}
