using Eco.Gameplay.Skills;
using Eco.Gameplay.Systems.TextLinks;

namespace Eco.Mods.TechTree
{
    using System;
    using System.Collections.Generic;
    using Eco.Core.Items;
    using Eco.Gameplay.Components;
    using Eco.Gameplay.Components.Auth;
    using Eco.Gameplay.Items;
    using Eco.Gameplay.Objects;
    using Eco.Shared.Math;
    using Eco.Shared.Localization;
    using Eco.Shared.Serialization;
    
    [Serialized]
    [LocDisplayName("Wood Cart Red")]
    [Weight(15000)]  
    [Ecopedia("CavRnMods", "Colored Vehicles", createAsSubPage: true, display: InPageTooltip.DynamicTooltip)]          
    [Tag("ColoredWoodCart", 1)]
    public partial class WoodCartRedItem : WorldObjectItem<WoodCartRedObject>
    {
        public override LocString DisplayDescription { get { return Localizer.DoStr("Small red cart for hauling small loads."); } }
    }
    
      
    public class PaintWoodCartRedRecipe : RecipeFamily
    {
        public PaintWoodCartRedRecipe()
        {
            this.Initialize(Localizer.DoStr("Paint Wood Cart Red"), typeof(PaintWoodCartRedRecipe));
            this.Recipes = new List<Recipe>
            {
                new Recipe(
                    "Paint Wood Cart Red",
                    Localizer.DoStr("Paint Wood Cart Red"),
                    new IngredientElement[]
                    {
                        new IngredientElement(typeof(WoodCartItem), 1, true), 
                        new IngredientElement(typeof(TomatoItem), 20, typeof(BasicEngineeringSkill), typeof(BasicEngineeringLavishResourcesTalent)),  
                    },
                    new CraftingElement<WoodCartRedItem>()
                )
            };
            this.ExperienceOnCraft = 0.1f;  
            this.LaborInCalories = CreateLaborInCaloriesValue(250, typeof(BasicEngineeringSkill), typeof(PaintWoodCartRedRecipe), this.UILink()); 
            this.CraftMinutes = CreateCraftTimeValue(typeof(PaintWoodCartRedRecipe), this.UILink(), 5, typeof(BasicEngineeringSkill));    

            this.Initialize(Localizer.DoStr("Paint Wood Cart Red"), typeof(PaintWoodCartRedRecipe));
            CraftingComponent.AddRecipe(typeof(PrimitivePaintingTableObject), this);
        }
    }

    [Serialized]
    [RequireComponent(typeof(StandaloneAuthComponent))]
    [RequireComponent(typeof(PublicStorageComponent))]
    [RequireComponent(typeof(MovableLinkComponent))]
    [RequireComponent(typeof(VehicleComponent))]
    [RequireComponent(typeof(ModularStockpileComponent))]
    [RequireComponent(typeof(TailingsReportComponent))]
    public partial class WoodCartRedObject : PhysicsWorldObject, IRepresentsItem
    {
        static WoodCartRedObject()
        {
            WorldObject.AddOccupancy<WoodCartRedObject>(new List<BlockOccupancy>(0));
        }

        public override LocString DisplayName { get { return Localizer.DoStr("Wood Cart Red"); } }
        public Type RepresentedItemType { get { return typeof(WoodCartRedItem); } }


        private WoodCartRedObject() { }

        protected override void Initialize()
        {
            base.Initialize();
            
            this.GetComponent<PublicStorageComponent>().Initialize(12, 2000000);           
            this.GetComponent<VehicleComponent>().Initialize(12, 1, 1);
            this.GetComponent<VehicleComponent>().HumanPowered(1);           
            this.GetComponent<StockpileComponent>().Initialize(new Vector3i(2,1,2));  
        }
    }
}
