using Eco.Gameplay.Skills;
using Eco.Gameplay.Systems.TextLinks;

namespace Eco.Mods.TechTree
{
    using System;
    using System.Collections.Generic;
    using Eco.Core.Items;
    using Eco.Gameplay.Components;
    using Eco.Gameplay.Components.Auth;
    using Eco.Gameplay.Items;
    using Eco.Gameplay.Objects;
    using Eco.Shared.Math;
    using Eco.Shared.Localization;
    using Eco.Shared.Serialization;
    
    [Serialized]
    [LocDisplayName("Wood Cart Technical Red")]
    [Weight(15000)]  
    [Ecopedia("CavRnMods", "Colored Vehicles", createAsSubPage: true, display: InPageTooltip.DynamicTooltip)]     
    [Tag("ColoredWoodCart", 1)]
    public partial class WoodCartTechnicalRedItem : WorldObjectItem<WoodCartTechnicalRedObject>
    {
        public override LocString DisplayDescription { get { return Localizer.DoStr("Small technical red cart for hauling small loads."); } }
    }
    
      
    public class PaintWoodCartTechnicalRedRecipe : RecipeFamily
    {
        public PaintWoodCartTechnicalRedRecipe()
        {
            this.Initialize(Localizer.DoStr("Paint Wood Cart Technical Red"), typeof(PaintWoodCartTechnicalRedRecipe));
            this.Recipes = new List<Recipe>
            {
                new Recipe(
                    "Paint Wood Cart Technical Red",
                    Localizer.DoStr("Paint Wood Cart Technical Red"),
                    new IngredientElement[]
                    {
                        new IngredientElement(typeof(WoodCartItem), 1, true), 
                        new IngredientElement(typeof(TomatoItem), 12, typeof(BasicEngineeringSkill), typeof(BasicEngineeringLavishResourcesTalent)),  
                        new IngredientElement(typeof(SandstoneItem), 8, typeof(BasicEngineeringSkill), typeof(BasicEngineeringLavishResourcesTalent)),
                    },
                    new CraftingElement<WoodCartTechnicalRedItem>()
                )
            };
            this.ExperienceOnCraft = 0.1f;  
            this.LaborInCalories = CreateLaborInCaloriesValue(250, typeof(BasicEngineeringSkill), typeof(PaintWoodCartTechnicalRedRecipe), this.UILink()); 
            this.CraftMinutes = CreateCraftTimeValue(typeof(PaintWoodCartTechnicalRedRecipe), this.UILink(), 5, typeof(BasicEngineeringSkill));    

            this.Initialize(Localizer.DoStr("Paint Wood Cart Technical Red"), typeof(PaintWoodCartTechnicalRedRecipe));
            CraftingComponent.AddRecipe(typeof(PrimitivePaintingTableObject), this);
        }
    }

    [Serialized]
    [RequireComponent(typeof(StandaloneAuthComponent))]
    [RequireComponent(typeof(PublicStorageComponent))]
    [RequireComponent(typeof(MovableLinkComponent))]
    [RequireComponent(typeof(VehicleComponent))]
    [RequireComponent(typeof(ModularStockpileComponent))]
    [RequireComponent(typeof(TailingsReportComponent))]
    public partial class WoodCartTechnicalRedObject : PhysicsWorldObject, IRepresentsItem
    {
        static WoodCartTechnicalRedObject()
        {
            WorldObject.AddOccupancy<WoodCartTechnicalRedObject>(new List<BlockOccupancy>(0));
        }

        public override LocString DisplayName { get { return Localizer.DoStr("Wood Cart Technical Red"); } }
        public Type RepresentedItemType { get { return typeof(WoodCartTechnicalRedItem); } }


        private WoodCartTechnicalRedObject() { }

        protected override void Initialize()
        {
            base.Initialize();
            
            this.GetComponent<PublicStorageComponent>().Initialize(12, 2000000);           
            this.GetComponent<VehicleComponent>().Initialize(12, 1, 1);
            this.GetComponent<VehicleComponent>().HumanPowered(1);           
            this.GetComponent<StockpileComponent>().Initialize(new Vector3i(2,1,2));  
        }
    }
}
